import moment from 'moment';
import { history } from 'umi';
import type { PropsWithChildren } from 'react';
import React, { useEffect, useRef, useState } from 'react';
import type { FormInstance } from 'antd';
import { Badge, Button } from 'antd';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import { PageContainer, ProTable } from '@ant-design/pro-components';
import type { UploadTaskResult } from '../data';
import { uploadTaskList } from '../service';
import renderSize from '@/global';
import { PlusOutlined } from '@ant-design/icons';
import CustomizeConfig from '@/services/customizeConfig';
const { APIDomain } = CustomizeConfig;
const UploadList: React.FC<PropsWithChildren<any>> = (props) => {
  const routeUrl = props.match.url;
  const [searchParams, setSearchParams] = useState(props.location.state?.searchParams || {});

  const actionRef = useRef<ActionType>();
  const searchRef = useRef<FormInstance>();
  useEffect(() => {
    history.replace(routeUrl, { searchParams });
    searchRef.current?.setFieldsValue({
      ...searchParams,
    });
  }, [routeUrl, searchParams]);

  const columns: ProColumns<UploadTaskResult>[] = [
    {
      title: '模糊查询账号',
      hideInTable: true,
      dataIndex: 'keyWords',
    },
    { title: 'ID', dataIndex: 'ut_id', search: false },
    { title: '名字', dataIndex: 'name' },
    {
      title: '状态',
      dataIndex: 'status',
      search: false,
      render: (val) => {
        if (val == 1) {
          return <Badge status="default" text="等待上传" />;
        } else if (val == 2) {
          return <Badge status="processing" text="等待合并" />;
        } else if (val == 3) {
          return <Badge status="warning" text="正在合并" />;
        } else if (val == 4) {
          return <Badge status="success" text="合并完成" />;
        } else if (val == 5) {
          return <Badge status="error" text="合并失败" />;
        } else {
          return '';
        }
      },
    },
    {
      title: '文件大小',
      dataIndex: 'size',
      search: false,
      render: (val) => renderSize(val),
    },
    {
      title: 'MD5',
      dataIndex: 'md5',
      search: false,
      render: (val) => <code>{val}</code>,
    },
    {
      title: '创建时间',
      dataIndex: 'create_time',
      search: false,
      render: (val) =>
        typeof val === 'number' && val > 0 ? moment(val * 1000).format('YYYY-MM-DD HH:mm:ss') : '-',
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <Button
          key="download"
          type="link"
          onClick={() => {
            window.open(`${APIDomain}${record.path}`);
            // const xhr = new XMLHttpRequest();
            // xhr.open('GET', `${APIDomain}${record.path}`, true);
            // xhr.responseType = 'blob';
            // xhr.onload = function () {
            //   const urlCreator = window.URL || window.webkitURL;
            //   const videoUrl = urlCreator.createObjectURL(this.response);
            //   const tag = document.createElement('a');
            //   tag.href = videoUrl;
            //   tag.target = '_blank';
            //   tag.download = record.name;
            //   document.body.appendChild(tag);
            //   tag.click();
            //   document.body.removeChild(tag);
            // };
            // xhr.onerror = (err) => {
            //   console.log('err', err)
            // };
            // xhr.send();
          }}
        >
          下载
        </Button>,
      ],
    },
  ];
  return (
    <PageContainer>
      <ProTable<UploadTaskResult, API.PageParams>
        headerTitle="文件列表"
        scroll={{ x: 1300 }}
        actionRef={actionRef}
        formRef={searchRef}
        rowKey="ut_id"
        search={{
          labelWidth: 'auto',
        }}
        pagination={{
          defaultCurrent: searchParams.current || 1,
          defaultPageSize: searchParams.pageSize || 10,
          showSizeChanger: true,
          pageSizeOptions: ['10', '20', '50', '100'],
        }}
        toolBarRender={() => [
          <Button
            key="upload"
            type="primary"
            onClick={() => {
              history.push(`/example/fragment_upload/upload`);
            }}
          >
            <PlusOutlined /> 上传文件
          </Button>,
        ]}
        request={async (params, sort) => {
          const d = {
            ...searchParams,
            current: params.current,
            pageSize: params.pageSize,
          };
          setSearchParams({ ...d });
          return uploadTaskList(d, sort).then(({ data }) => {
            return {
              data: data?.data || [],
              success: true,
              total: data?.total || 0,
            };
          });
        }}
        columns={columns}
        onSubmit={(params) => {
          setSearchParams({ ...searchParams, ...params, current: 1 });
        }}
        onReset={() => {
          setSearchParams({});
        }}
      />
    </PageContainer>
  );
};
export default UploadList;
